==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QGenericPluginFactory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qgenericpluginfactory.h>
#include <QtCore/QVariant>
#include <QtCore/QStringList>
#include <QtCore/qobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QGenericPluginFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGenericPluginFactory")
    QGenericPluginFactory *_ptr = reinterpret_cast<QGenericPluginFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QGenericPluginFactory_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QGenericPluginFactory *__qt_this = new(__qtjambi_ptr) QGenericPluginFactory();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QGenericPluginFactory
void __qt_destruct_QGenericPluginFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGenericPluginFactory")
    reinterpret_cast<QGenericPluginFactory*>(ptr)->~QGenericPluginFactory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGenericPluginFactory::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QGenericPluginFactory_initialize_1native__Lio_qt_gui_QGenericPluginFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGenericPluginFactory::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGenericPluginFactory_0, sizeof(QGenericPluginFactory), typeid(QGenericPluginFactory), false, &deleter_QGenericPluginFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGenericPluginFactory::create(QString,QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QGenericPluginFactory_create__Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring arg__1,
 jstring arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGenericPluginFactory::create(QString,QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_arg__1 = qtjambi_cast<QString >(__jni_env, arg__1);
        QString  __qt_arg__2 = qtjambi_cast<QString >(__jni_env, arg__2);
        QObject* __qt_return_value = QGenericPluginFactory::create(__qt_arg__1, __qt_arg__2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGenericPluginFactory::keys()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QGenericPluginFactory_keys__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGenericPluginFactory::keys()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QGenericPluginFactory::keys();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGenericPluginFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QGenericPluginFactory>("QGenericPluginFactory", "io/qt/gui/QGenericPluginFactory");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGenericPluginFactory, {
        ConstructorInfo(&__qt_construct_QGenericPluginFactory_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGenericPluginFactory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QGenericPluginFactory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qgenericpluginfactory.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QGenericPluginFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGenericPluginFactory")
    QGenericPluginFactory *_ptr = reinterpret_cast<QGenericPluginFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QGenericPluginFactory()
void __qt_construct_QGenericPluginFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGenericPluginFactory()")
    Q_UNUSED(__java_arguments)
    QGenericPluginFactory *__qt_this = new(__qtjambi_ptr) QGenericPluginFactory();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QGenericPluginFactory::QGenericPluginFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QGenericPluginFactory_initialize_1native__Lio_qt_gui_QGenericPluginFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGenericPluginFactory::QGenericPluginFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGenericPluginFactory, sizeof(QGenericPluginFactory), typeid(QGenericPluginFactory), 0, false, &deleter_QGenericPluginFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGenericPluginFactory
void __qt_destruct_QGenericPluginFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGenericPluginFactory")
    reinterpret_cast<QGenericPluginFactory*>(ptr)->~QGenericPluginFactory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGenericPluginFactory::create(QString,QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QGenericPluginFactory_create__Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring arg__1,
 jstring arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGenericPluginFactory::create(QString,QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QString  __qt_arg__2 = qtjambi_cast<QString>(__jni_env, arg__2);
        QObject* __qt_return_value = QGenericPluginFactory::create(__qt_arg__1, __qt_arg__2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGenericPluginFactory::keys()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QGenericPluginFactory_keys__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGenericPluginFactory::keys()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QGenericPluginFactory::keys();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGenericPluginFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QGenericPluginFactory>("QGenericPluginFactory", "io/qt/gui/QGenericPluginFactory");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QGenericPluginFactory, {
        ConstructorInfo(&__qt_construct_QGenericPluginFactory, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGenericPluginFactory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
